.. AUTO-GENERATED FILE -- DO NOT EDIT!

.. toctree::

   generated/ISLP
   generated/ISLP.bart.bart
   generated/ISLP.bart.likelihood
   generated/ISLP.bart.particle_tree
   generated/ISLP.bart.tree
   generated/ISLP.cluster
   generated/ISLP.models
   generated/ISLP.models.columns
   generated/ISLP.models.generic_selector
   generated/ISLP.models.model_spec
   generated/ISLP.models.sklearn_wrap
   generated/ISLP.models.strategy
   generated/ISLP.pygam
   generated/ISLP.survival
   generated/ISLP.svm
   generated/ISLP.torch
   generated/ISLP.torch.imdb
   generated/ISLP.torch.lightning
   generated/ISLP.transforms
